import { StackState, ProgressState } from './cdk-toolkit';
interface CliOption {
    readonly app?: string;
    readonly output?: string;
    readonly verbose?: number;
    readonly noColor?: boolean;
    readonly stackName?: string;
}
/**
 * Get default environment.
 *
 * Used by sst cli.
 *
 * @param options CLI options
 *
 * @returns {
 *    environment: { account, region }
 *  }
 */
export declare function sstEnv(options?: CliOption): Promise<{
    environment: {
        account: string | undefined;
        region: string;
    };
}>;
/**
 * Bootstrap and returns the boostrapped environment. Only returns 1 environment.
 *
 * Used by sst cli.
 *
 * @param options CLI options
 *
 * @returns {
 *    environment: { account, region }
 *  }
 */
export declare function sstBootstrap(options?: CliOption): Promise<any>;
/**
 * Synth all stacks, and returns synthesized stacks.
 *
 * Used by sst cli.
 *
 * @param options CLI options
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstSynth(options?: CliOption): Promise<any>;
/**
 * Deploy a single stack exclusively or deploy all stacks, and returns deployed stacks.
 *
 * Used by sst cli.
 *
 * @param options CLI options
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstDeploy(options?: CliOption): Promise<{
    name: string;
    status: string;
}[]>;
/**
 * Deploy all stacks in parallel asynchronously, and returns the environment deployed to and progress state.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param force always deploy stack even if templates are identical.
 * @param stackStates stackStates from the previous call.
 *
 * @returns { account, region, status: 'no_resources' | 'unchanged' | 'deploying'  }
 */
export declare function sstDeployAsync(outputPath: string, force: boolean, stackStates?: StackState[]): Promise<ProgressState>;
/**
 * Destroy a single stack exclusively or destroy all stacks, and returns destroyed stacks.
 *
 * Used by sst cli.
 *
 * @param options CLI options
 *
 * @returns { stacks: [{ id, name }] }
 */
export declare function sstDestroy(options?: CliOption): Promise<any>;
/**
 * Destroy a single stack asynchronously, and returns destroy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be destroy.
 *
 * @returns { account, region, status: 'destroying' | 'destroyed'  }
 */
export declare function sstDestroyAsync(outputPath: string, stackName: string): Promise<any>;
/**
 * Get asynchronous destroy status.
 *
 * Used by deploy workflow.
 *
 * @param outputPath the path to cdk.out folder.
 * @param stackName the stack to be destroyed.
 *
 * @returns { status: 'destroying' | 'destroyed'  }
 */
export declare function sstDestroyStatus(outputPath: string, stackName: string): Promise<{
    status: string;
}>;
export {};
